============
Installation
============

To avoid version confliction among dependencies, we highly recommend using conda virtual environment::

    $ conda create -n emase jupyter
    $ source activate emase
    (emase) $ conda install -c kbchoi emase

Or if you have virtualenvwrapper installed::

    $ mkvirtualenv emase
    $ pip install emase

Or at the command line::

    $ easy_install emase

